#
# spec file for package batctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           batctl
Version:        2024.1
Release:        1.1
Summary:        B.A.T.M.A.N. advanced control and management tool
License:        GPL-2.0-only AND MIT
Group:          Productivity/Networking/Other
URL:            https://www.open-mesh.org/projects/batctl
Source0:        https://downloads.open-mesh.org/batman/stable/sources/batctl/%{name}-%{version}.tar.gz
Source1:        https://downloads.open-mesh.org/batman/stable/sources/batctl/%{name}-%{version}.tar.gz.asc
Source2:        batctl.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libnl-3.0)

%description
Why do I need batctl?  B.A.T.M.A.N. advanced operates on layer 2 and
thus all hosts participating in the virtual switch are completely
transparent for all protocols above layer 2.  Therefore the common
diagnosis tools do not work as expected.  To overcome these problems
batctl was created.  At the moment batctl contains ping, traceroute,
tcpdump and interfaces to the kernel module settings.

%prep
%setup -q

%build
export CFLAGS='%{optflags}'
%make_build

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man8
install -m 644 man/%{name}.8 %{buildroot}%{_mandir}/man8
install -m 755 %{name} %{buildroot}%{_bindir}

%files
%license LICENSES/preferred/GPL-2.0 LICENSES/preferred/MIT
%doc CHANGELOG.rst README.rst
%{_bindir}/%{name}
%{_mandir}/man8/%{name}.8%{ext_man}

%changelog
* Wed Sep 25 2024 ming li <mli@suse.com>
- update to 2024.1:
  * (no changes)
* Wed Feb 21 2024 ming li <mli@suse.com>
- update to 2024.0:
  * Add stateless multicast packet format support
  * bugs squashed: Fix various length checks in tcpdump-like subcommand
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.3:
  * (no changes)
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.1:
  * Synchronize with kernel headers
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.0:
  * (no changes)
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 2022.3:
  - drop additional delay after the ping packet
  * manpage cleanups
  * add various commands to print generic netlink replies as JSON
  * coding style cleanups and refactoring
* Thu May 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2021.0
  * Drop support for batman-adv's sysfs+debugfs
  * Drop support for automatic destruction of empty meshifs
  * Drop support for deprecated log command support
  * Drop of the legacy vis subcommands
  * Add per interface hop penalty command
  * Add tcpdump support for MCAST TVLV, unicast fragments and coded
    packets
  * Add support for hardif specific settings
  * Add multicast_fanout setting subcommand
  * Add hop_penalty setting subcommand
  * Add gateway selection manpage section for B.A.T.M.A.N. V
  * New subcommand "event" to receive netlink notifications
  * Bugs squashed:
  * Fix query of meshif's ap_isolation status
  * Ignore "interface already exists" error during "interface add"
  * Fix endianness in ICMPv6 Echo Request/Reply parsing
  * Fix parsing of radiotap headers on big endian systems
  * Fix error code on throughputmeter errors
  * Re-integrate support for translation table unicast/multicast
    filter
  * Avoid incorrect warning about disabled mesh interface when
    debugfs support is not enabled in batman-adv
  * Allow to select routing algorithm during creation of interface
  * implement support for multicast RTR flags
  * avoid some kernel deprecation warning by using more generic
    netlink over sysfs
  * use type specific prefixes to select mesh interface or vlan
    instead of '-m'
  * implement netlink based support for remaining sysfs-only features
  * remove non-netlink support for translating MAC addresses to originators
  * introduce support for batadv meshif, hardif and vlan configuration via netlink
  * replace multicast_mode with multicast_forceflood settings subcommand
* Sun Jun 10 2018 antoine.belvire@opensuse.org
- Update to version 2018.1.
  * Synchronization of batman-adv netlink and packet headers.
  * Add DAT cache and multicast flags netlink support.
  * Disable translation support for non-unicast mac addresses.
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 2017.3
  * See the following for all changes:
    https://www.open-mesh.org/projects/open-mesh/news
- Cleanup with spec-cleaner
* Thu Jan  5 2017 p.drouand@gmail.com
- Update to version 2016.5
  * reimplement traceroute/ping commands in userspace without debugfs
  * switch interface manipulation from (legacy) sysfs to rtnetlink
  * coding style cleanups
- Changes from version 2016.4
  * integrate support for batman-adv netlink
  * coding style cleanups
  * documentation updates
  * bugs squashed:
  - fix endless loop in TP meter on some platforms
  - fix build errors caused by name conflicts
* Fri Oct 21 2016 p.drouand@gmail.com
- Update to version 2016.3
  * synchronize common headers with batman-adv
  * support multicast logging and debug table
  * split tcpdump OGM packet filter in OGM and OGMv2 filter
  * add infrastructure to communicate with batadv netlink family
  * integrate command to control new kernel throughput meter
* Wed Feb 10 2016 p.drouand@gmail.com
- Update to version 2016.0
  * No changelog available
* Thu Aug 27 2015 p.drouand@gmail.com
- Update to version 2015.1
  * No changelog available
* Sun Jul 26 2015 p.drouand@gmail.com
- Update to version 2015.0
  * No changelog available
* Mon Mar 30 2015 p.drouand@gmail.com
- Update to version 2014.4.0
  * No ChangeLog available
* Mon Dec 22 2014 p.drouand@gmail.com
- Update to version 2014.3.0
  + support latest kernels (2.6.29 - 3.16)
  + drop QinQ claim frames in bridge loop avoidance
  + fix a bogus warning from batadv_is_on_batman_iface()
  + removed SET_ETHTOOL_OPS
  + style improvements:
  * remove semi-colon after macro definition
  * add blank line between declarations and the rest of the code
- Add make dependencies to pkg-config and pkgconfig(libnl-3.0);
  new upstream requirements
- Fix Url to batctl homepage
- Use download Url as source
* Sat Dec  8 2012 p.drouand@gmail.com
- Update to 2012.4.0 version:
  * now maintains a list of optional features and informs the user
    about a possibly deactivated optional feature.
  * the sysfs / debugfs code has been refactored to remove redundant
    boilerplate code.
  * option to display the newly added backbone gateway table
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue May 24 2011 gregkh@suse.de
- initial creation of the batctl package, based on 2011.1.0 release.
